@@ -27,6 +27,7 @@ from resolvelib.structs import DirectedGraph
 from rich.tree import Tree
 
 from pdm import termui
+from pdm.compat import importlib_metadata as im
 from pdm.exceptions import PdmArgumentError, PdmUsageError, ProjectError
 from pdm.formats import FORMATS
 from pdm.formats.base import make_array, make_inline_table
@@ -38,9 +39,8 @@ from pdm.models.requirements import (
     strip_extras,
 )
 from pdm.models.specifiers import get_specifier
-from pdm.models.working_set import WorkingSet
 from pdm.project import Project
-from pdm.utils import is_path_relative_to, url_to_path
+from pdm.utils import is_path_relative_to, normalize_name, url_to_path
 
 if TYPE_CHECKING:
     from resolvelib.resolvers import RequirementInformation, ResolutionImpossible
@@ -69,7 +69,7 @@ class ErrorArgumentParser(argparse.ArgumentParser):
 class PdmFormatter(argparse.RawDescriptionHelpFormatter):
     def start_section(self, heading: str | None) -> None:
         return super().start_section(
-            termui.style(heading.title() if heading else "", style="bold yellow")
+            termui.style(heading.title() if heading else "", style="warning")
         )
 
     def _format_usage(
@@ -83,7 +83,7 @@ class PdmFormatter(argparse.RawDescriptionHelpFormatter):
             prefix = "Usage: "
         result = super()._format_usage(usage, actions, groups, prefix)
         if prefix:
-            return result.replace(prefix, termui.style(prefix, style="bold yellow"))
+            return result.replace(prefix, termui.style(prefix, style="warning"))
         return result
 
     def _format_action(self, action: Action) -> str:
@@ -111,7 +111,7 @@ class PdmFormatter(argparse.RawDescriptionHelpFormatter):
             indent_first = help_position
 
         # collect the pieces of the action help
-        parts = [termui.style(action_header, style="cyan")]
+        parts = [termui.style(action_header, style="primary")]
 
         # if there was help for the action, add lines of help text
         if action.help:
@@ -156,7 +156,10 @@ class Package:
 
 
 def build_dependency_graph(
-    working_set: WorkingSet, marker_env: dict[str, str] | None = None
+    working_set: Mapping[str, im.Distribution],
+    marker_env: dict[str, str] | None = None,
+    selected: set[str] | None = None,
+    include_sub: bool = True,
 ) -> DirectedGraph:
     """Build a dependency graph from locked result."""
     graph: DirectedGraph[Package | None] = DirectedGraph()
@@ -189,14 +192,25 @@ def build_dependency_graph(
             if extras:
                 node_with_extras.add(name)
             graph.add(node)
-
-            for k in reqs:
-                child = add_package(k, working_set.get(strip_extras(k)[0]))
-                graph.connect(node, child)
+            if include_sub:
+                for k in reqs:
+                    child = add_package(k, working_set.get(strip_extras(k)[0]))
+                    graph.connect(node, child)
 
         return node
 
+    selected_map: dict[str, str] = {}
+    for key in selected or ():
+        name = key.split("[")[0]
+        if len(key) >= len(selected_map.get(name, "")):
+            # Ensure key with extras remains
+            selected_map[name] = key
     for k, dist in working_set.items():
+        if selected is not None:
+            name = k.split("[")[0]
+            if name not in selected_map:
+                continue
+            k = selected_map[name]
         add_package(k, dist)
     for node in list(graph):
         if node is not None and not list(graph.iter_parents(node)):
@@ -229,20 +243,20 @@ def add_package_to_tree(
     :param visited: the visited package collection
     """
     version = (
-        "[red][ not installed ][/]"
+        "[error][ not installed ][/]"
         if not package.version
-        else f"[red]{package.version}[/]"
+        else f"[error]{package.version}[/]"
         if required
         and required not in ("Any", "This project")
         and not SpecifierSet(required).contains(package.version)
-        else f"[yellow]{package.version}[/]"
+        else f"[warning]{package.version}[/]"
     )
     # escape deps with extras
     name = package.name.replace("[", r"\[") if "[" in package.name else package.name
     if package.name in visited:
-        version = r"[red]\[circular][/]"
+        version = r"[error]\[circular][/]"
     required = f"[ required: {required} ]" if required else "[ Not required ]"
-    node = root.add(f"[bold green]{name}[/] {version} {required}")
+    node = root.add(f"[req]{name}[/] {version} {required}")
     if package.name in visited:
         return
     children = sorted(graph.iter_children(package), key=lambda p: p.name)
@@ -261,14 +275,14 @@ def add_package_to_reverse_tree(
 ) -> None:
     """Format one package for output reverse dependency graph."""
     version = (
-        "[red][ not installed ][/]"
+        "[error][ not installed ][/]"
         if not package.version
-        else f"[yellow]{package.version}[/]"
+        else f"[warning]{package.version}[/]"
     )
     if package.name in visited:
-        version = r"[red]\[circular][/]"
+        version = r"[error]\[circular][/]"
     requires = (
-        f"[ requires: [red]{requires}[/] ]"
+        f"[ requires: [error]{requires}[/] ]"
         if requires not in ("Any", "")
         and child
         and child.version
@@ -278,7 +292,7 @@ def add_package_to_reverse_tree(
         else f"[ requires: {requires} ]"
     )
     name = package.name.replace("[", r"\[") if "[" in package.name else package.name
-    node = root.add(f"[bold green]{name}[/] {version} {requires}")
+    node = root.add(f"[req]{name}[/] {version} {requires}")
 
     if package.name in visited:
         return
@@ -296,8 +310,8 @@ def add_package_to_reverse_tree(
 def package_is_project(package: Package, project: Project) -> bool:
     return (
         not project.environment.is_global
-        and bool(project.name)
-        and package.name == project.meta.project_name.lower()
+        and project.name is not None
+        and package.name == normalize_name(project.name)
     )
 
 
@@ -512,11 +526,11 @@ def save_version_specifiers(
 
 def check_project_file(project: Project) -> None:
     """Check the existence of the project file and throws an error on failure."""
-    if not project.meta:
+    if not project.pyproject.is_valid:
         raise ProjectError(
             "The pyproject.toml has not been initialized yet. You can do this "
-            "by running [green]`pdm init`[/]."
-        )
+            "by running [success]`pdm init`[/]."
+        ) from None
 
 
 def find_importable_files(project: Project) -> Iterable[tuple[str, Path]]:
@@ -576,7 +590,7 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
         result = [
             "Unable to find a resolution because the following dependencies don't work "
             "on all Python versions defined by the project's `requires-python`: "
-            f"[green]{str(project_requires.specifier)}[/]."
+            f"[success]{str(project_requires.specifier)}[/]."
         ]
         for req, parent in conflicting:
             info_lines.add(f"  {req.as_line()} (from {repr(parent)})")
@@ -590,24 +604,22 @@ def format_resolution_impossible(err: ResolutionImpossible) -> str:
     if len(causes) == 1:
         return (
             "Unable to find a resolution for "
-            f"[green]{causes[0].requirement.identify()}[/]\n"
+            f"[success]{causes[0].requirement.identify()}[/]\n"
             "Please make sure the package name is correct."
         )
 
     result = [
         "Unable to find a resolution for "
-        f"[green]{causes[0].requirement.identify()}[/]\n"
+        f"[success]{causes[0].requirement.identify()}[/]\n"
         "because of the following conflicts:"
     ]
     for req, parent in causes:
-        info_lines.add(
-            f"  {req.as_line()} (from {repr(parent) if parent else 'project'})"
-        )
+        info_lines.add(f"  {req.as_line()} (from {parent if parent else 'project'})")
     result.extend(sorted(info_lines))
     result.append(
         "To fix this, you could loosen the dependency version constraints in "
         "pyproject.toml. See https://pdm.fming.dev/latest/usage/dependency/"
-        "/#solve-the-locking-failure for more details."
+        "#solve-the-locking-failure for more details."
     )
     return "\n".join(result)
 
@@ -616,8 +628,8 @@ def translate_groups(
     project: Project, default: bool, dev: bool, groups: Iterable[str]
 ) -> list[str]:
     """Translate default, dev and groups containing ":all" into a list of groups"""
-    optional_groups = set(project.meta.optional_dependencies or [])
-    dev_groups = set(project.tool_settings.get("dev-dependencies", []))
+    optional_groups = set(project.pyproject.metadata.get("optional-dependencies", {}))
+    dev_groups = set(project.pyproject.settings.get("dev-dependencies", {}))
     groups_set = set(groups)
     if dev is None:
         dev = True
@@ -638,7 +650,7 @@ def translate_groups(
     invalid_groups = groups_set - set(project.iter_groups())
     if invalid_groups:
         project.core.ui.echo(
-            f"[d]Ignoring non-existing groups: [green]{', '.join(invalid_groups)}[/]",
+            f"[d]Ignoring non-existing groups: [success]{', '.join(invalid_groups)}[/]",
             err=True,
         )
         groups_set -= invalid_groups
@@ -693,7 +705,7 @@ def get_dist_location(dist: Distribution) -> str:
     direct_url_data = json.loads(direct_url)
     url = cast(str, direct_url_data["url"])
     if url.startswith("file:"):
-        path = url_to_path(url).replace("/${PROJECT_ROOT}", ".")
+        path = url_to_path(url)
         editable = direct_url_data.get("dir_info", {}).get("editable", False)
         return f"{'-e ' if editable else ''}{path}"
     return ""
